@@ -1,13 +1,13 @@
 (*********************************************************************************)
 (*                Cameleon                                                       *)
 (*                                                                               *)
-(*    Copyright (C) 2005 Institut National de Recherche en Informatique et       *)
-(*    en Automatique. All rights reserved.                                       *)
+(*    Copyright (C) 2004-2009 Institut National de Recherche en Informatique     *)
+(*    et en Automatique. All rights reserved.                                    *)
 (*                                                                               *)
 (*    This program is free software; you can redistribute it and/or modify       *)
 (*    it under the terms of the GNU Library General Public License as            *)
 (*    published by the Free Software Foundation; either version 2 of the         *)
-(*    License, or  any later version.                                            *)
+(*    License, or any later version.                                             *)
 (*                                                                               *)
 (*    This program is distributed in the hope that it will be useful,            *)
 (*    but WITHOUT ANY WARRANTY; without even the implied warranty of             *)
@@ -23,7 +23,7 @@
 (*                                                                               *)
 (*********************************************************************************)
 
-(* $Id: cam_doc_gui.ml 182 2006-03-12 16:43:02Z zoggy $ *)
+(* $Id: cam_doc_gui.ml 717 2009-09-22 05:40:58Z zoggy $ *)
 
 (** Gui for doc searching and browsing. *)
 
@@ -888,19 +888,20 @@ class text_doc =
       self#add_link buffer#end_iter#offset (String.length s) [ LinkCode t.ty_loc ] ;
       buffer#insert ~tags:[fixed_bold_font] (s^" ") ;
       (match t.ty_manifest with
-	None -> ()
-      | Some typ ->
-	  buffer#insert ~tags:[fixed_font] "= " ;
-	  self#put_type_expr father typ ;
-	  buffer#insert ~tags:[fixed_font] " "
-      );
-      (match t.ty_kind with
-	Type_abstract ->
-	  buffer#insert "\n"
-      |	Type_variant (l, pv) ->
-	  buffer#insert ~tags:[fixed_font] ("= "^(if pv then "private" else "")^"\n") ;
-	  let f constr =
-	    self#put_keyword "   | " ;
+           None -> ()
+         | Some typ ->
+             buffer#insert ~tags:[fixed_font] "= " ;
+             self#put_type_expr father typ ;
+             buffer#insert ~tags:[fixed_font] " "
+        );
+        (match t.ty_kind with
+           Type_abstract ->
+             buffer#insert "\n"
+         | Type_variant l ->
+             buffer#insert ~tags:[fixed_font]
+               ("= "^(if t.ty_private = Private then "private" else "")^"\n") ;
+             let f constr =
+               self#put_keyword "   | " ;
 	    self#put_constructor constr.vc_name ;
 	    (match constr.vc_args with
 	      [] -> ()
@@ -919,8 +920,9 @@ class text_doc =
 	  in
 	  List.iter f l
 
-      |	Type_record (l, pv) ->
-	  buffer#insert ~tags:[fixed_font] ("= "^(if pv then "private " else "")^"{\n");
+      |	Type_record l ->
+	  buffer#insert ~tags:[fixed_font]
+               ("= "^(if t.ty_private = Private then "private " else "")^"{\n");
 	  let f r =
 	    buffer#insert ~tags:[fixed_font] "   " ;
 	    (if r.rf_mutable then self#put_keyword "mutable " else ()) ;
