@@ -1,13 +1,13 @@
 (*********************************************************************************)
 (*                Cameleon                                                       *)
 (*                                                                               *)
-(*    Copyright (C) 2005 Institut National de Recherche en Informatique et       *)
-(*    en Automatique. All rights reserved.                                       *)
+(*    Copyright (C) 2004-2009 Institut National de Recherche en Informatique     *)
+(*    et en Automatique. All rights reserved.                                    *)
 (*                                                                               *)
 (*    This program is free software; you can redistribute it and/or modify       *)
 (*    it under the terms of the GNU Library General Public License as            *)
 (*    published by the Free Software Foundation; either version 2 of the         *)
-(*    License, or  any later version.                                            *)
+(*    License, or any later version.                                             *)
 (*                                                                               *)
 (*    This program is distributed in the hope that it will be useful,            *)
 (*    but WITHOUT ANY WARRANTY; without even the implied warranty of             *)
@@ -68,13 +68,13 @@ let color_included_module = new O.string_cp ~group: Cam_rc.gui_ini
     ["modules_view" ; "colors" ; "included_module"] "Grey" ""
 
 let open_source_command =  new O.string_cp ~group: Cam_rc.gui_ini
-    ["modules_view" ; "open_source_command"] "system emacsclient -n" ""
+    ["modules_view" ; "open_source_command"] "chamo_open_file" ""
 
 let f_open_file ?(char=0) file =
-  let com = Printf.sprintf "%s +%d %s"
+  let com = Printf.sprintf "%s %s %d"
       open_source_command#get
-      ((Cam_misc.line_of_char file char)+1)
       (Filename.quote file)
+      ((Cam_misc.line_of_char file char)+1)
   in
   Cam_commands.eval_command com
 
