@@ -1,28 +1,3 @@
-(*********************************************************************************)
-(*                Cameleon                                                       *)
-(*                                                                               *)
-(*    Copyright (C) 2005 Institut National de Recherche en Informatique et       *)
-(*    en Automatique. All rights reserved.                                       *)
-(*                                                                               *)
-(*    This program is free software; you can redistribute it and/or modify       *)
-(*    it under the terms of the GNU Library General Public License as            *)
-(*    published by the Free Software Foundation; either version 2 of the         *)
-(*    License, or  any later version.                                            *)
-(*                                                                               *)
-(*    This program is distributed in the hope that it will be useful,            *)
-(*    but WITHOUT ANY WARRANTY; without even the implied warranty of             *)
-(*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the              *)
-(*    GNU Library General Public License for more details.                       *)
-(*                                                                               *)
-(*    You should have received a copy of the GNU Library General Public          *)
-(*    License along with this program; if not, write to the Free Software        *)
-(*    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA                   *)
-(*    02111-1307  USA                                                            *)
-(*                                                                               *)
-(*    Contact: Maxence.Guesdon@inria.fr                                          *)
-(*                                                                               *)
-(*********************************************************************************)
-
 val login : string
 module Constant :
   sig
@@ -51,6 +26,8 @@ module Constant :
     val com_display_doc_box : string
     val com_about_box : string
     val com_list_commands : string
+    val com_prompt_command : string
+    val com_on_exit : string
   end
 module Commands :
   sig
@@ -62,12 +39,39 @@ module Commands :
       com_more_args : string option;
       com_f : command;
     }
-    val register : command_desc -> unit
+    val register :
+      ?table:(string, command_desc) Hashtbl.t ->
+      ?replace:bool -> command_desc -> unit
+    val register_before :
+      ?table:(string, command_desc) Hashtbl.t -> command_desc -> unit
+    val register_after :
+      ?table:(string, command_desc) Hashtbl.t -> command_desc -> unit
+    val get_com :
+      ?table:(string, command_desc) Hashtbl.t -> string -> command_desc
+    val get_com_or_fail :
+      ?table:(string, command_desc) Hashtbl.t -> string -> command_desc
     val string_to_argv : string -> string array
-    val launch_command : string -> string array -> unit
-    val ask_launch_command : ?width:int -> string -> string array -> unit
-    val eval_command : string -> unit
-    val available_command_names : unit -> string list
+    val argv_to_string : string array -> string
+    val launch_command :
+      ?history:bool ->
+      ?table:(string, command_desc) Hashtbl.t ->
+      string -> string array -> unit
+    val same_previous_command : unit -> bool
+    val ask_launch_command :
+      ?history:bool ->
+      ?table:(string, command_desc) Hashtbl.t ->
+      ?width:int -> string -> string array -> unit
+    val eval_command :
+      ?history:bool ->
+      ?table:(string, command_desc) Hashtbl.t -> string -> unit
+    val available_command_names :
+      ?table:(string, command_desc) Hashtbl.t -> unit -> string list
+    val unit_com : string -> (unit -> unit) -> command_desc
+    val create_com :
+      string -> ?more:string -> string array -> command -> command_desc
+    val set_global : string -> string -> unit
+    val get_global : string -> string
+    val safe_get_global : string -> string
   end
 module Config : sig val debug_level : int val socket_dir : string end
 module Dbg : sig val print : ?level:int -> string -> unit end
@@ -75,6 +79,7 @@ module Misc :
   sig
     val map_opt : ('a -> 'b) -> 'a option -> 'b option
     val chop_n_char : int -> string -> string
+    val my_int_of_string : string -> int
     val list_remove_doubles : ?pred:('a -> 'a -> bool) -> 'a list -> 'a list
     val add_shortcut :
       < connect : < destroy : callback:(unit -> unit) -> GtkSignal.id; .. >;
@@ -94,6 +99,11 @@ module Misc :
     val subdirs : string -> string list
     val line_of_char : string -> int -> int
     val replace_in_string : pat:string -> subs:string -> s:string -> string
+    val escape_menu_label : string -> string
+    val utf8_index_of_char : string -> int -> int
+    val utf8_char_of_index : string -> int -> int
+    val utf8_string_length : string -> int
+    val utf8_char_of_code : int -> string
   end
 module View :
   sig
@@ -379,6 +389,7 @@ module Cam_files :
     val default_ft_handlers : (string * string list) list
     val ft_rules : (file_type * string) O.list_cp
     val ft_handlers : (file_type * string list) O.list_cp
+    val default_open_file_command : O.string_cp
     module C :
       sig
         type parameter_kind = Configwin.parameter_kind
@@ -541,20 +552,23 @@ module Cam_files :
     val file_type_handlers : (file_type, string list) Hashtbl.t
     val associate_handler : file_type -> string -> unit
     val command_on_files : string -> string list -> unit
-    val escape_menu_label : string -> string
-    val edition_commands_menu_entries : string -> GToolbox.menu_entry list
+    val edition_commands_menu_entries :
+      ?line:int -> string -> GToolbox.menu_entry list
     val popup_file_commands_menu : string -> unit
     val _configure_ft_rules : 'a -> unit
     val _configure_ft_handlers : 'a -> unit
   end
 module Hooks :
   sig
-    val set_display_message : (string -> unit) -> unit
-    val set_error_message : (string -> unit) -> unit
-    val set_warning_message : (string -> unit) -> unit
-    val display_message : string -> unit
-    val error_message : string -> unit
-    val warning_message : string -> unit
+    val set_display_message : (?to_utf8:bool -> string -> unit) -> unit
+    val set_error_message : (?to_utf8:bool -> string -> unit) -> unit
+    val set_warning_message : (?to_utf8:bool -> string -> unit) -> unit
+    val display_message : ?to_utf8:bool -> string -> unit
+    val error_message : ?to_utf8:bool -> string -> unit
+    val warning_message : ?to_utf8:bool -> string -> unit
+    val get_display_message : unit -> ?to_utf8:bool -> string -> unit
+    val get_error_message : unit -> ?to_utf8:bool -> string -> unit
+    val get_warning_message : unit -> ?to_utf8:bool -> string -> unit
   end
 module Doc_gui :
   sig
@@ -588,7 +602,6 @@ module Modules_view :
         val software_author : string
         val software_author_mail : string
         val software_copyright : string
-        val software_about : string
         val about : string
         val bad_format : string -> string
         val loading_file : string -> string
