@@ -146,7 +146,7 @@ module <![module_name]!> = functor (Sql : Dbf_sql_driver.SqlDriver) ->
   struct
     type t = {
         <?iter:name=column [columns]?>
-        <![col_name column]!> : <![col_ocaml_ty true column]!> ;
+        mutable <![col_name column]!> : <![col_ocaml_ty true column]!> ;
         <?/iter?>
       }
 
@@ -306,10 +306,11 @@ module <![module_name]!> = functor (Sql : Dbf_sql_driver.SqlDriver) ->
         <?/if?><?/iter?>
       end
 
-    let select_where = fun db condition ->
+    let select_where = fun db ?(table_alias="") condition ->
       let query =
         Printf.sprintf
-          "SELECT <![sql_columns]!> FROM <![table_name]!> %s"
+          "SELECT <![sql_columns]!> FROM <![table_name]!> %s %s"
+          table_alias
           (match Dbf_sql_misc.no_blanks condition with
             "" -> ""
           | _ -> Printf.sprintf "WHERE %s" condition
@@ -355,10 +356,11 @@ module <![module_name]!> = functor (Sql : Dbf_sql_driver.SqlDriver) ->
       in
       Sql.map result ~f:(fun r -> log_row_as_record (to_array r))
 
-    let select_log_where = fun db condition ->
+    let select_log_where = fun db ?(table_alias="") condition ->
       let query =
         Printf.sprintf
-          "SELECT log_who, log_date, log_action, <![sql_columns]!> FROM <![log_table_name]!> %s"
+          "SELECT log_who, log_date, log_action, <![sql_columns]!> FROM <![log_table_name]!> %s %s"
+          table_alias
           (match Dbf_sql_misc.no_blanks condition with
             "" -> ""
           | _ -> Printf.sprintf "WHERE %s" condition
@@ -407,9 +409,9 @@ module <![module_name]!> = functor (Sql : Dbf_sql_driver.SqlDriver) ->
         ignore (Sql.exec db query)
     <?/if?>
 
-    let delete_where = fun db condition ->
+    let delete_where = fun db ?(table_alias="") condition ->
       <?if [table.ta_logged]?>
-      let impacted = match select_where db condition with
+      let impacted = match select_where db ~table_alias condition with
         | Sql.R_Ok
         | Sql.R_Empty -> []
         | Sql.R_Fetch cursor -> fetch_all cursor
@@ -417,7 +419,8 @@ module <![module_name]!> = functor (Sql : Dbf_sql_driver.SqlDriver) ->
       <?/if?>
       let query =
         Printf.sprintf
-          "DELETE FROM <![table_name]!> %s"
+          "DELETE FROM <![table_name]!> %s %s"
+          table_alias
           (match Dbf_sql_misc.no_blanks condition with
             "" -> ""
           | _ -> Printf.sprintf "WHERE %s" condition
