@@ -1,13 +1,13 @@
 (*********************************************************************************)
 (*                Cameleon                                                       *)
 (*                                                                               *)
-(*    Copyright (C) 2005 Institut National de Recherche en Informatique et       *)
-(*    en Automatique. All rights reserved.                                       *)
+(*    Copyright (C) 2004-2009 Institut National de Recherche en Informatique     *)
+(*    et en Automatique. All rights reserved.                                    *)
 (*                                                                               *)
 (*    This program is free software; you can redistribute it and/or modify       *)
 (*    it under the terms of the GNU Library General Public License as            *)
 (*    published by the Free Software Foundation; either version 2 of the         *)
-(*    License, or  any later version.                                            *)
+(*    License, or any later version.                                             *)
 (*                                                                               *)
 (*    This program is distributed in the hope that it will be useful,            *)
 (*    but WITHOUT ANY WARRANTY; without even the implied warranty of             *)
@@ -121,7 +121,7 @@ module Revisions :
 (** Manipulating differences between two files. *)
 module Diffs :
   sig
-    type diffs
+    type diffs = Odiff.diffs
     val display_diffs : ?on_close: (unit -> unit) ->
       title: string -> file: string -> diffs -> unit
 
