@@ -1,13 +1,13 @@
 (*********************************************************************************)
 (*                Cameleon                                                       *)
 (*                                                                               *)
-(*    Copyright (C) 2005 Institut National de Recherche en Informatique et       *)
-(*    en Automatique. All rights reserved.                                       *)
+(*    Copyright (C) 2004-2009 Institut National de Recherche en Informatique     *)
+(*    et en Automatique. All rights reserved.                                    *)
 (*                                                                               *)
 (*    This program is free software; you can redistribute it and/or modify       *)
 (*    it under the terms of the GNU Library General Public License as            *)
 (*    published by the Free Software Foundation; either version 2 of the         *)
-(*    License, or  any later version.                                            *)
+(*    License, or any later version.                                             *)
 (*                                                                               *)
 (*    This program is distributed in the hope that it will be useful,            *)
 (*    but WITHOUT ANY WARRANTY; without even the implied warranty of             *)
@@ -547,7 +547,7 @@ class gui files =
       let fb = new file label f_opt in
       let eb = GBin.event_box () in
       fb#reparent eb#coerce;
-      notebook#append_page ~tab_label: label#coerce eb#coerce;
+      ignore(notebook#append_page ~tab_label: label#coerce eb#coerce);
       file_boxes <- file_boxes @ [fb];
       notebook#goto_page ((List.length file_boxes) - 1)
 
