@@ -1,13 +1,13 @@
 (*********************************************************************************)
 (*                Cameleon                                                       *)
 (*                                                                               *)
-(*    Copyright (C) 2005 Institut National de Recherche en Informatique et       *)
-(*    en Automatique. All rights reserved.                                       *)
+(*    Copyright (C) 2004-2009 Institut National de Recherche en Informatique     *)
+(*    et en Automatique. All rights reserved.                                    *)
 (*                                                                               *)
 (*    This program is free software; you can redistribute it and/or modify       *)
 (*    it under the terms of the GNU Library General Public License as            *)
 (*    published by the Free Software Foundation; either version 2 of the         *)
-(*    License, or  any later version.                                            *)
+(*    License, or any later version.                                             *)
 (*                                                                               *)
 (*    This program is distributed in the hope that it will be useful,            *)
 (*    but WITHOUT ANY WARRANTY; without even the implied warranty of             *)
@@ -27,7 +27,7 @@
 
 (* $Id$ *)
 
-(*c==m=[OCaml_conf]=0.1=t==*)
+(*c==m=[OCaml_conf]=0.3=t==*)
 
 
   open Sys
@@ -85,7 +85,7 @@ let is_suffix ~suf s =
   String.sub s (len_s - len_suf) len_suf = suf
 
 
-(** [crete_temp_files ?ext ?contents ()] creates a temporary empty file and
+(** [create_temp_files ?ext ?contents ()] creates a temporary empty file and
    returns its name. The prefix of the file is specified by {!temp_files_prefix}.
    @param ext can be used to indicate a extension different from {!temp_files_ext}.
    @param contents can be used to specify the content of the file.
@@ -99,8 +99,10 @@ let create_temp_file ?(ext= !temp_files_ext) ?(contents="") () =
   file
 
 
+let remove_empty_strings = List.filter ((<>) "")
+
 let string_of_includes l =
-  String.concat " " (List.map (fun s -> "-I "^(Filename.quote s)) l)
+  String.concat " " (List.map (fun s -> "-I "^(Filename.quote s)) (remove_empty_strings l))
 
 (** If the given filename has a [.cmo] (resp. [.cma]) extension,
   then return the same filename with a [.cmx] (resp. [.cmxa]) extension.*)
@@ -250,6 +252,32 @@ let input_lines chan =
     | None -> List.rev lines in
   all []
 
+(** [unlink_f file] removes the given [file] if it exists.
+   If the files is a [.ml] file (resp. a [.mli] file), then
+   it also removes the [.cmo], [.cmx], [.o] and [.cmi] files
+   (resp. the [.cmi] file) if they exist.
+   @raise Unix.Unix_error if an error occurs.
+*)
+let unlink_f file =
+  if !debug then ()
+  else
+    let files =
+      if Filename.check_suffix file ".mli" then
+        [file; (Filename.chop_extension file)^".cmi"]
+      else
+        if Filename.check_suffix file ".ml" then
+          let base = Filename.chop_extension file in
+          [file; base^".cmi" ; base^".cmo" ; base^".cmx"; base^".o" ]
+	else
+          [file]
+    in
+    let f file =
+      try unlink file with Unix_error (ENOENT, _, _) -> ()
+    in
+    List.iter f files
+
+
+
 (** {2:exec Handling processes} *)
 
 exception Exec_failure;;
@@ -285,31 +313,6 @@ type redirection =
   | Silent                        (** >/dev/null 2>&1 *)
 ;;
 
-(** [unlink_f file] removes the given [file] if it exists.
-   If the files is a [.ml] file (resp. a [.mli] file), then
-   it also removes the [.cmo], [.cmx], [.o] and [.cmi] files
-   (resp. the [.cmi] file) if they exist.
-   @raise Unix.Unix_error if an error occurs.
-*)
-let unlink_f file =
-  if !debug then ()
-  else
-    let files =
-      if Filename.check_suffix file ".mli" then
-	[file; (Filename.chop_extension file)^".cmi"]
-      else
-	if Filename.check_suffix file ".ml" then
-	  let base = Filename.chop_extension file in
-	  [file; base^".cmi" ; base^".cmo" ; base^".cmx"; base^".o" ]
-	else
-	  [file]
-    in
-    let f file =
-      try unlink file with Unix_error (ENOENT, _, _) -> ()
-    in
-    List.iter f files
-
-
 let execvp_redirect redirections cmd args  =
   let perm = 0o640 in
   let temp_file =
@@ -666,36 +669,37 @@ let string_of_com_args com args =
     (String.concat " "
        (List.map Filename.quote (Array.to_list args)))
 
-let can_compile mode conf ?(includes=[]) file =
+let can_compile mode conf ?(includes=[]) ?(options=[]) file =
   let ocamlc = ocamlc_of_mode conf mode in
   let args = Array.of_list
       (
        "-c" ::
-       (List.flatten (List.map (fun s -> [ "-I" ; s]) includes)) @
+       (List.flatten (List.map (fun s -> [ "-I" ; s]) (remove_empty_strings includes))) @
+       options @
        [file]
       )
   in
   add_to_log (string_of_com_args ocamlc args);
   exec_status_ok (execvp_redirect [Out_append_to_file !log_file;Err_to_out] ocamlc args)
 
-let can_compile_prog ?mes mode conf ?includes prog =
+let can_compile_prog ?mes mode conf ?includes ?options prog =
   (match mes with None -> () | Some s -> !print s);
   let res =
     handle_unix_error (fun () ->
       let file = create_temp_file ~contents: prog () in
-      try_finalize (can_compile mode conf ?includes) file unlink_f file) ()
+      try_finalize (can_compile mode conf ?includes ?options) file unlink_f file) ()
   in
   (match mes with None -> () | Some _ -> !print ((!string_of_bool res)^"\n"));
   res
 ;;
 
-let ocaml_defined ?mes mode conf ?includes v =
+let ocaml_defined ?mes mode conf ?includes ?options v =
   handle_unix_error (fun () ->
     let prog = Printf.sprintf "let _ = %s;;\n" v in
-    can_compile_prog ?mes mode conf ?includes prog) ()
+    can_compile_prog ?mes mode conf ?includes ?options prog) ()
 ;;
 
-let ocaml_value_has_type ?mes mode conf ?includes v t =
+let ocaml_value_has_type ?mes mode conf ?includes ?options v t =
   handle_unix_error (fun () ->
     let prog = Printf.sprintf "let (_ : %s) = %s;;\n" t v in
     can_compile_prog ?mes mode conf ?includes prog) ()
@@ -720,8 +724,9 @@ let can_link ?mes mode conf ?out ?(includes=[]) ?(libs=[]) ?(options=[]) files =
       (
        "-linkall" ::
        "-o" :: outfile ::
-       (List.flatten (List.map (fun s -> ["-I"; s]) includes)) @
+       (List.flatten (List.map (fun s -> ["-I"; s]) (remove_empty_strings includes))) @
        libs @
+       options @
        files
       )
   in
@@ -801,11 +806,14 @@ let add_conf_variables c =
    List.iter (fun (var,v) -> add_subst var v) l
 
 
-(*/c==m=[OCaml_conf]=0.1=t==*)
+(*/c==m=[OCaml_conf]=0.3=t==*)
 
-(*c==v=[OCaml_conf.detect_lablgtk2]=0.1====*)
+(*c==v=[OCaml_conf.detect_lablgtk2]=0.3====*)
 let detect_lablgtk2 ?(modes=[`Byte;`Opt]) conf =
-  let includes = ["default install", ["+lablgtk2"]] in
+  let includes =
+    ["default install",
+      [Filename.concat (ocaml_libdir conf) "lablgtk2"]]
+  in
   let includes =
     match ocamlfind_query conf "lablgtk2" with
       None -> includes
@@ -819,21 +827,25 @@ let detect_lablgtk2 ?(modes=[`Byte;`Opt]) conf =
     can_link ~mes mode conf ~includes ~libs []
   in
   let rec iter = function
-      [] -> ("", [])
+      [] -> ([], [])
     | incs :: q ->
 	let f = f incs in
 	if List.for_all f modes then
-	  (string_of_includes (snd incs), libs)
+	  (snd incs, libs)
 	else
 	  iter q
   in
   iter includes
-(*/c==v=[OCaml_conf.detect_lablgtk2]=0.1====*)
+(*/c==v=[OCaml_conf.detect_lablgtk2]=0.3====*)
 
 
-(*c==v=[OCaml_conf.detect_xml_light]=0.1====*)
+(*c==v=[OCaml_conf.detect_xml_light]=0.3====*)
 let detect_xml_light ?(modes=[`Byte;`Opt]) conf =
-  let includes = ["default install", []] in
+  let includes =
+     ["default install", [] ;
+      "+xml-light style", [Filename.concat (ocaml_libdir conf) "xml-light"] ;
+     ]
+  in
   let includes =
     match ocamlfind_query conf "xml-light" with
       None -> includes
@@ -847,21 +859,74 @@ let detect_xml_light ?(modes=[`Byte;`Opt]) conf =
     can_link ~mes mode conf ~includes ~libs []
   in
   let rec iter = function
-      [] -> ("", [])
+      [] -> ([], [])
     | incs :: q ->
 	let f = f incs in
 	if List.for_all f modes then
-	  (string_of_includes (snd incs), libs)
+	  (snd incs, libs)
 	else
 	  iter q
   in
   iter includes
-(*/c==v=[OCaml_conf.detect_xml_light]=0.1====*)
+(*/c==v=[OCaml_conf.detect_xml_light]=0.3====*)
+
+let detect_lablgtksourceview2 ?(modes=[`Byte;`Opt]) conf =
+  let includes =
+    ["default install",
+      List.map (Filename.concat (ocaml_libdir conf)) ["lablgtk2"]]
+  in
+  let includes =
+    match ocamlfind_query conf "lablgtksourceview2" with
+      None -> includes
+    | Some s ->
+	match ocamlfind_query conf "lablgtksourceview2" with
+	  None -> includes
+	| Some s2 -> ("with ocamlfind", [s2;s]) :: includes
+  in
+  let libs = ["lablgtk.cma" ; "lablgtksourceview2.cma"] in
+  let f (mes, includes) mode =
+    let mes = Printf.sprintf "checking for Lablgtksourceview2 (%s) %s... "
+	(string_of_mode mode) mes
+    in
+    can_link ~mes mode conf ~includes ~libs []
+  in
+  let rec iter = function
+      [] -> ([], [])
+    | incs :: q ->
+	let f = f incs in
+	if List.for_all f modes then
+	  (snd incs, libs)
+	else
+	  iter q
+  in
+  iter includes
+;;
+
+let detect_pcre ?(modes=[`Byte;`Opt]) conf =
+  match ocamlfind_query conf "pcre" with
+    None ->
+      !fatal_error (Printf.sprintf "pcre-ocaml could not be found with ocamlfind.");
+      []
+  | Some d ->
+      let includes = [d] in
+      let f mode =
+        let mes = Printf.sprintf "checking for pcre-ocaml (%s)... "
+            (string_of_mode mode)
+        in
+        if can_link ~mes mode conf ~includes ~libs: ["pcre.cma"] [] then
+          ()
+        else
+          !fatal_error (Printf.sprintf "Could not link with pcre-ocaml (%s)" (string_of_mode mode))      in
+      List.iter f modes;
+      includes
+;;
 
 let ocaml_required = [3;9;1]
-let conf = ocaml_conf ~withopt: true  ();;
+let conf = ocaml_conf ();;
 print_conf conf;;
 
+let modes = if conf.ocamlopt <> "" then [`Byte;`Opt] else [`Byte];;
+
 let _ =
   if conf.version << ocaml_required then
     let msg = Printf.sprintf "Error: OCaml %s required, but found %s."
@@ -871,14 +936,75 @@ let _ =
 
 let _ = !print "\n### checking required tools and libraries ###\n"
 let _ =
-  match detect_xml_light conf with
-    "", [] -> !fatal_error "Could not link with Xml-light"
-  | s, _ -> add_subst "XMLLIGHT_INCLUDES" s
+  match detect_xml_light ~modes conf with
+    [], [] -> !fatal_error "Could not link with Xml-light"
+  | l, _ -> add_subst "XMLLIGHT_INCLUDES" (string_of_includes l)
+
+let pcre_includes =
+  match detect_pcre ~modes conf with
+    [] -> failwith "pcre-ocaml not found."
+  | l -> l
+
+let _ = add_subst "PCRE_INCLUDES" (string_of_includes pcre_includes)
+let _ = add_subst "PCREDIR" (List.hd pcre_includes)
 
 let _ =
-  match detect_lablgtk2 conf with
-    "", [] -> !fatal_error "Could not link with LablGtk2"
-  | s, _ -> add_subst "LABLGTK2_INCLUDES" s
+  let prog = "assert Pcre.config_utf8;;" in
+  let f mode =
+    let prog = create_temp_file ~contents: prog ~ext: "ml" () in
+    let out = "./testpcre.x" in
+    let mes = Printf.sprintf
+      "Testing compiling a pcre program to check for UTF-8 support [%s]..."
+      (string_of_mode mode)
+    in
+    if can_link ~mes
+      mode conf ~out ~includes: pcre_includes ~libs: ["pcre.cma"] [prog]
+    then
+      (
+       unlink_f prog;
+       if not (try_run out) then
+         (
+          unlink_f out;
+          !fatal_error "Pcre-OCaml has no UTF-8 support."
+         )
+       else
+         unlink_f out
+      )
+    else
+      !fatal_error "Compilation failed."
+  in
+  List.iter f modes
+
+
+let _ =
+  match detect_lablgtk2 ~modes conf with
+    [], [] -> !fatal_error "Could not link with LablGtk2"
+  | l, _ ->
+      add_subst "LABLGTK2_INCLUDES" (string_of_includes l);
+      add_subst "LABLGTK2DIR" (List.hd l)
+
+let _ =
+  let (incs,b) =
+    match detect_lablgtksourceview2 ~modes conf with
+      [], [] -> ("",false)
+    | l, _ -> (string_of_includes l,true)
+  in
+  add_subst "LABLGTKSOURCEVIEW_INCLUDES" incs;
+  add_subst "USE_LABLGTKSOURCEVIEW" (if b then "yes" else "no");
+  add_subst "CAMTOP_SOURCEVIEW_MODULE"
+    (if b then "Camtop_sourceview" else "Camtop_textview");
+  add_subst "CAMTOP_SOURCEVIEW_MODULE_CMO"
+    (if b then "camtop_sourceview.cmo" else "camtop_textview.cmo");
+  add_subst "LABLGTKSOURCEVIEW_CMA"
+    (if b then "lablgtksourceview2.cma" else "");
+  add_subst "LABLGTKSOURCEVIEW_CMXA"
+    (if b then "lablgtksourceview2.cmxa" else "")
+
+let _ =
+  match exec_and_get_first_line "pkg-config" [| "--cflags-only-I" ; "gtk+-2.0" |] with
+    "" -> failwith "Could not get includes for gtk+-2.0"
+  | s ->
+      add_subst "GTK_INCLUDES" s
 
 let _ =
   let lablgladecc =
@@ -892,10 +1018,14 @@ let _ =
   add_subst "LABLGLADECC" lablgladecc
 let _ = !print "\n###\n"
 
+let _ =
+  add_subst "OCAMLDOC_PLUGINSDIR"
+    (exec_and_get_first_line conf.ocamldoc [|"-customdir"|])
+
 let _ = add_conf_variables conf
 
 let _ =
   if Array.length Sys.argv < 2 then
     !fatal_error "No output file given for substitutions!"
   else
-    output_substs_to_file Sys.argv.(1)
+    output_substs_to_file Sys.argv.(1);;
